==> classpath-0.16.tar.gz: classpath-0.16/gnu/CORBA/fixedTypeCode.java <==
/* fixedTypeCode.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package gnu.CORBA;

import java.math.BigDecimal;

import org.omg.CORBA.TCKind;
import org.omg.CORBA.TypeCode;
import org.omg.CORBA.TypeCodePackage.BadKind;

/**
 * A typecode for CORBA <code>fixed</code>
 * @author Audrius Meskauskas (AudriusA@Bioinformatics.org)
 */
public class fixedTypeCode
  extends primitiveTypeCode
{
  /**
   * The number of the used digits.
   */
  private short digits;

  /**
   * The number of the digits after the decimal point.
   */
  private short scale;

  /**
   * Creates the instance of the fixed type code.
   */
  public fixedTypeCode()
  {
    super(TCKind.tk_fixed);
  }

  /**
   * Creates the instance of the fixed type code,
   * setting the digits and scale by example.
   */
  public fixedTypeCode(BigDecimal example)
  {
    super(TCKind.tk_fixed);
    if (example != null)
      {
        setScale(example.scale());
        setDigits(countDigits(example));
      }
  }

  /**
   * Set the number of digits.
   */
  public void setDigits(int a_digits)
  {
    this.digits = (short) a_digits;
  }

  /**
   * Set the number of digits after the decimal point.
   */
  public void setScale(int a_scale)
  {
    this.scale = (short) a_scale;
  }

  /**
   * Get the number of digits in thid BigDecimal
   *
   * @param x a BigDecimal to check.
   */
  public static int countDigits(BigDecimal number)
  {
    return number.unscaledValue().abs().toString().length();
  }

  public boolean equals(Object other)
  {
    if (other == this)
      {
        return true;
      }
    if (!(other instanceof TypeCode))
      {
        return false;
      }
    try
      {
        TypeCode that = (TypeCode) other;
        return kind() == that.kind() && digits == that.fixed_digits() &&
               scale == that.fixed_scale();
      }
    catch (BadKind ex)
      {
        return false;
      }
  }

  /**
   * Get the number of digits.
   */
  public short fixed_digits()
  {
    return digits;
  }

  /**
   * Get the number of digits after the decimal point.
   */
  public short fixed_scale()
  {
    return scale;
  }
}

==> classpath-0.17.tar.gz: classpath-0.17/gnu/CORBA/fixedTypeCode.java <==
/* fixedTypeCode.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package gnu.CORBA;

import java.math.BigDecimal;

import org.omg.CORBA.TCKind;
import org.omg.CORBA.TypeCode;
import org.omg.CORBA.TypeCodePackage.BadKind;

/**
 * A typecode for CORBA <code>fixed</code>
 * @author Audrius Meskauskas (AudriusA@Bioinformatics.org)
 */
public class fixedTypeCode
  extends primitiveTypeCode
{
  /**
   * The number of the used digits.
   */
  private short digits;

  /**
   * The number of the digits after the decimal point.
   */
  private short scale;

  /**
   * Creates the instance of the fixed type code.
   */
  public fixedTypeCode()
  {
    super(TCKind.tk_fixed);
  }

  /**
   * Creates the instance of the fixed type code,
   * setting the digits and scale by example.
   */
  public fixedTypeCode(BigDecimal example)
  {
    super(TCKind.tk_fixed);
    if (example != null)
      {
        setScale(example.scale());
        setDigits(countDigits(example));
      }
  }

  /**
   * Set the number of digits.
   */
  public void setDigits(int a_digits)
  {
    this.digits = (short) a_digits;
  }

  /**
   * Set the number of digits after the decimal point.
   */
  public void setScale(int a_scale)
  {
    this.scale = (short) a_scale;
  }

  /**
   * Get the number of digits in thid BigDecimal
   *
   * @param x a BigDecimal to check.
   */
  public static int countDigits(BigDecimal number)
  {
    return number.unscaledValue().abs().toString().length();
  }

  public boolean equals(Object other)
  {
    if (other == this)
      {
        return true;
      }
    if (!(other instanceof TypeCode))
      {
        return false;
      }
    try
      {
        TypeCode that = (TypeCode) other;
        return kind() == that.kind() && digits == that.fixed_digits() &&
               scale == that.fixed_scale();
      }
    catch (BadKind ex)
      {
        return false;
      }
  }

  /**
   * Get the number of digits.
   */
  public short fixed_digits()
  {
    return digits;
  }

  /**
   * Get the number of digits after the decimal point.
   */
  public short fixed_scale()
  {
    return scale;
  }
}
